@@ -125,14 +125,14 @@ class Http implements AdapterInterface
      *
      * @var bool
      */
-    protected $imaProxy;
+    protected $imaProxy = false;
 
     /**
      * Flag indicating the client is IE and didn't bother to return the opaque string
      *
      * @var bool
      */
-    protected $ieNoOpaque;
+    protected $ieNoOpaque = false;
 
     /**
      * Constructor
@@ -149,10 +149,6 @@ class Http implements AdapterInterface
      */
     public function __construct(array $config)
     {
-        $this->request  = null;
-        $this->response = null;
-        $this->ieNoOpaque = false;
-
         if (empty($config['accept_schemes'])) {
             throw new Exception\InvalidArgumentException('Config key "accept_schemes" is required');
         }
@@ -181,6 +177,9 @@ class Http implements AdapterInterface
         }
 
         if (in_array('digest', $this->acceptSchemes)) {
+            $this->useOpaque = true;
+            $this->algo = 'MD5';
+
             if (empty($config['digest_domains']) ||
                 !ctype_print($config['digest_domains']) ||
                 strpos($config['digest_domains'], '"') !== false) {
@@ -204,22 +203,16 @@ class Http implements AdapterInterface
             // We use the opaque value unless explicitly told not to
             if (isset($config['use_opaque']) && false == (bool) $config['use_opaque']) {
                 $this->useOpaque = false;
-            } else {
-                $this->useOpaque = true;
             }
 
             if (isset($config['algorithm']) && in_array($config['algorithm'], $this->supportedAlgos)) {
-                $this->algo = $config['algorithm'];
-            } else {
-                $this->algo = 'MD5';
+                $this->algo = (string) $config['algorithm'];
             }
         }
 
         // Don't be a proxy unless explicitly told to do so
         if (isset($config['proxy_auth']) && true == (bool) $config['proxy_auth']) {
             $this->imaProxy = true;  // I'm a Proxy
-        } else {
-            $this->imaProxy = false;
         }
     }
 
@@ -727,7 +720,7 @@ class Http implements AdapterInterface
         if (!$ret || empty($temp[1])) {
             return false;
         }
-        if (32 != strlen($temp[1]) || !ctype_xdigit($temp[1])) {
+        if (!$this->isValidMd5Hash($temp[1])) {
             return false;
         }
 
@@ -778,7 +771,7 @@ class Http implements AdapterInterface
 
             // This implementation only sends MD5 hex strings in the opaque value
             if (!$this->ieNoOpaque &&
-                (32 != strlen($temp[1]) || !ctype_xdigit($temp[1]))) {
+                !$this->isValidMd5Hash($temp[1])) {
                 return false;
             }
 
@@ -811,8 +804,17 @@ class Http implements AdapterInterface
         }
 
         $data['nc'] = $temp[1];
-        $temp = null;
 
         return $data;
     }
+
+    /**
+     * validates if $value is a valid Md5 hash
+     * @param string $value
+     * @return bool
+     */
+    private function isValidMd5Hash($value)
+    {
+        return 32 == strlen($value) && ctype_xdigit($value);
+    }
 }
